@@ -1,4 +1,4 @@
-def set_profile_8MRL120_15_LEn2_200(lib, id):
+def set_profile_8MRL120_15_LEn2_100(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -18,7 +18,7 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
         FEEDBACK_ENC_REVERSE = 1
         FEEDBACK_ENC_TYPE_AUTO = 0
     feedback_settings.FeedbackFlags = FeedbackFlags_.FEEDBACK_ENC_TYPE_DIFFERENTIAL | FeedbackFlags_.FEEDBACK_ENC_REVERSE | FeedbackFlags_.FEEDBACK_ENC_TYPE_AUTO
-    feedback_settings.CountsPerTurn = 720000
+    feedback_settings.CountsPerTurn = 1440000
     result = lib.set_feedback_settings(id, byref(feedback_settings))
 
     if result != Result.Ok:
@@ -60,7 +60,7 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
     move_settings.uSpeed = 0
     move_settings.Accel = 9
     move_settings.Decel = 9
-    move_settings.AntiplaySpeed = 500
+    move_settings.AntiplaySpeed = 480
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -87,7 +87,7 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
     engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_LIMIT_CURR | EngineFlags_.ENGINE_ACCEL_ON
-    engine_settings.Antiplay = -27936
+    engine_settings.Antiplay = 10240
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -182,9 +182,9 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
-    edges_settings.LeftBorder = 18000
+    edges_settings.LeftBorder = 36000
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 702000
+    edges_settings.RightBorder = 1404000
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -290,8 +290,8 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 50
-    control_settings.MaxSpeed[1] = 500
+    control_settings.MaxSpeed[0] = 48
+    control_settings.MaxSpeed[1] = 480
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
@@ -446,7 +446,7 @@ def set_profile_8MRL120_15_LEn2_200(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 82, 76, 49, 50, 48, 45, 49, 53, 45, 76, 69, 110, 50, 45, 50, 48, 48, 0, 0, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 82, 76, 49, 50, 48, 45, 49, 53, 45, 76, 69, 110, 50, 45, 49, 48, 48, 0, 0, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
