@@ -1,4 +1,4 @@
-def set_profile_8MT173_20_E3(lib, id):
+def set_profile_8MT175_100_E3(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -10,7 +10,7 @@ def set_profile_8MT173_20_E3(lib, id):
         FEEDBACK_NONE = 5
         FEEDBACK_EMF = 4
         FEEDBACK_ENCODER = 1
-    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_EMF
+    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_NONE
     class FeedbackFlags_:
         FEEDBACK_ENC_TYPE_BITS = 192
         FEEDBACK_ENC_TYPE_DIFFERENTIAL = 128
@@ -31,8 +31,8 @@ def set_profile_8MT173_20_E3(lib, id):
     home_settings.uFastHome = 0
     home_settings.SlowHome = 500
     home_settings.uSlowHome = 0
-    home_settings.HomeDelta = 542
-    home_settings.uHomeDelta = 0
+    home_settings.HomeDelta = 626
+    home_settings.uHomeDelta = 200
     class HomeFlags_:
         HOME_USE_FAST = 256
         HOME_STOP_SECOND_BITS = 192
@@ -56,11 +56,11 @@ def set_profile_8MT173_20_E3(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 2000
+    move_settings.Speed = 1000
     move_settings.uSpeed = 0
     move_settings.Accel = 2000
-    move_settings.Decel = 5000
-    move_settings.AntiplaySpeed = 2000
+    move_settings.Decel = 4000
+    move_settings.AntiplaySpeed = 1000
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,8 +73,8 @@ def set_profile_8MT173_20_E3(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 360
-    engine_settings.NomCurrent = 670
+    engine_settings.NomVoltage = 1
+    engine_settings.NomCurrent = 1200
     engine_settings.NomSpeed = 4000
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
@@ -87,7 +87,7 @@ def set_profile_8MT173_20_E3(lib, id):
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
     engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 1800
+    engine_settings.Antiplay = 575
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -137,7 +137,7 @@ def set_profile_8MT173_20_E3(lib, id):
         POWER_SMOOTH_CURRENT = 4
         POWER_OFF_ENABLED = 2
         POWER_REDUCT_ENABLED = 1
-    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_REDUCT_ENABLED
+    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_OFF_ENABLED | PowerFlags_.POWER_REDUCT_ENABLED
     result = lib.set_power_settings(id, byref(power_settings))
 
     if result != Result.Ok:
@@ -182,9 +182,9 @@ def set_profile_8MT173_20_E3(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = -142
+    edges_settings.LeftBorder = 374
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 15058
+    edges_settings.RightBorder = 38374
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -197,8 +197,8 @@ def set_profile_8MT173_20_E3(lib, id):
     pid_settings.KpU = 0
     pid_settings.KiU = 0
     pid_settings.KdU = 0
-    pid_settings.Kpf = 0.006000000052154064
-    pid_settings.Kif = 0.05000000074505806
+    pid_settings.Kpf = 0.003599999938160181
+    pid_settings.Kif = 0.03799999877810478
     pid_settings.Kdf = 2.8000000384054147e-05
     result = lib.set_pid_settings(id, byref(pid_settings))
 
@@ -290,9 +290,9 @@ def set_profile_8MT173_20_E3(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 20
-    control_settings.MaxSpeed[1] = 200
-    control_settings.MaxSpeed[2] = 2000
+    control_settings.MaxSpeed[0] = 100
+    control_settings.MaxSpeed[1] = 1000
+    control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
     control_settings.MaxSpeed[5] = 0
@@ -361,7 +361,7 @@ def set_profile_8MT173_20_E3(lib, id):
         CTP_ALARM_ON_ERROR = 4
         CTP_BASE = 2
         CTP_ENABLED = 1
-    ctp_settings.CTPFlags = CTPFlags_.CTP_BASE
+    ctp_settings.CTPFlags = CTPFlags_.CTP_BASE | CTPFlags_.CTP_ENABLED
     result = lib.set_ctp_settings(id, byref(ctp_settings))
 
     if result != Result.Ok:
@@ -400,9 +400,9 @@ def set_profile_8MT173_20_E3(lib, id):
 
     emf_settings = emf_settings_t()
 
-    emf_settings.L = 0.005400000140070915
-    emf_settings.R = 7.400000095367432
-    emf_settings.Km = 0.0024999999441206455
+    emf_settings.L = 0
+    emf_settings.R = 0
+    emf_settings.Km = 0
     class BackEMFFlags_:
         BACK_EMF_KM_AUTO = 4
         BACK_EMF_RESISTANCE_AUTO = 2
@@ -446,7 +446,7 @@ def set_profile_8MT173_20_E3(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 84, 49, 55, 51, 45, 50, 48, 45, 69, 51, 0, 69, 51, 0, 69, 51, 0, 0, 0, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 84, 49, 55, 53, 45, 49, 48, 48, 45, 69, 51, 0, 52, 50, 0, 51, 0, 0, 0, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -455,10 +455,10 @@ def set_profile_8MT173_20_E3(lib, id):
 
     stage_settings = stage_settings_t()
 
-    stage_settings.LeadScrewPitch = 0.25
+    stage_settings.LeadScrewPitch = 0.5
     stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
-    stage_settings.MaxSpeed = 5
-    stage_settings.TravelRange = 20
+    stage_settings.MaxSpeed = 10
+    stage_settings.TravelRange = 100
     stage_settings.SupplyVoltageMin = 0
     stage_settings.SupplyVoltageMax = 0
     stage_settings.MaxCurrentConsumption = 0
@@ -581,8 +581,8 @@ def set_profile_8MT173_20_E3(lib, id):
 
     gear_settings = gear_settings_t()
 
-    gear_settings.ReductionIn = 1
-    gear_settings.ReductionOut = 1
+    gear_settings.ReductionIn = 0
+    gear_settings.ReductionOut = 0
     gear_settings.RatedInputTorque = 0
     gear_settings.RatedInputSpeed = 0
     gear_settings.MaxOutputBacklash = 0
@@ -614,7 +614,7 @@ def set_profile_8MT173_20_E3(lib, id):
         TS_TYPE_SEMICONDUCTOR = 2
         TS_TYPE_THERMOCOUPLE = 1
         TS_TYPE_UNKNOWN = 0
-    accessories_settings.TSSettings = TSSettings_.TS_TYPE_THERMOCOUPLE | TSSettings_.TS_TYPE_UNKNOWN
+    accessories_settings.TSSettings = TSSettings_.TS_TYPE_UNKNOWN
     class LimitSwitchesSettings_:
         LS_SHORTED = 16
         LS_SW2_ACTIVE_LOW = 8
